==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/report_abuse.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="report_abuse.php" method="post">

<table width="100%" cellpadding="0" cellspacing="0" border="0">
	<tr>
		<td width="760" valign="top">
			<div class="box_top">
				<?php echo $lang['hdr_report_abuse'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td valign="top">
						<table>
							<tr>
								<td>
									<b><?php echo $lang['hdr_report_abuse'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_report_txt'];?><br />
								</td>
							</tr>
						</table>
					</td>
					<td width="20">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
					</td>
					<td valign="top">
						<table>
							<tr>
								<td>
									<b><?php echo $lang['hdr_additional'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_additional_intro'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td>
									<textarea name="data[message]" rows="6" cols="50" class="formInput"></textarea><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td colspan="3">
						<hr />
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td align="right" colspan="3">
						<a href="<?php echo "http://" . $report_abuse_url;?>" class="link_stnd"><?php echo $lang['menu_back'];?></a>
						&nbsp;
						<input type="submit" name="send_report" value="<?php echo $lang['sub_report'];?>" class="button_urgent" /><br />
					</td>
				</tr>
		
			</table>
			</div>
			
			<div id="box_bottom">
			<table cellpadding="0" cellspacing="0" border="0" width="100%">
				<tr>
					<td align="left">
						<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
					</td>
					<td align="left">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
					</td>
					<td align="right">
						<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
					</td>
				</tr>
			</table>
			</div>
		</td>
	</tr>
</table>
</form>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

<table width="100%" cellpadding="2" cellspacing="0" border="0">
	<tr>
		<td valign="top">
			<b><?php echo $lang['txt_page'];?></b><br />
			<?php echo $lang['txt_page_txt'];?><br />
		</td>
	</tr>
	<tr>
		<td valign="top" class="picture">
			<?php echo $report_abuse_body;?><br />
		</td>
	</tr>
</table>

==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/template/barnraiser_01/report_abuse.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<form action="report_abuse.php" method="post">

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_report_abuse'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table width="100%" cellpadding="2" cellspacing="2" border="0">
				<tr>
					<td valign="top">
						<table>
							<tr>
								<td>
									<b><?php echo $lang['hdr_report_abuse'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_report_txt'];?><br />
								</td>
							</tr>
						</table>
					</td>
					<td width="20">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
					</td>
					<td valign="top">
						<table>
							<tr>
								<td>
									<b><?php echo $lang['hdr_additional'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_additional_intro'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td>
									<textarea name="message" rows="6" cols="50"></textarea><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td colspan="3">
						<hr />
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td align="right" colspan="3">
						<a href="<?php echo "http://" . $report_abuse_url;?>" class="link_stnd"><?php echo $lang['menu_back'];?></a>
						&nbsp;
						<input type="submit" name="send_report" value="<?php echo $lang['sub_report'];?>" class="button_urgent" /><br />
					</td>
				</tr>
		
			</table>
		</div>
	</div>
</div>
	
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>
</form>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

<table width="100%" cellpadding="2" cellspacing="0" border="0">
	<tr>
		<td valign="top">
			<b><?php echo $lang['txt_page'];?></b><br />
			<?php echo $lang['txt_page_txt'];?><br />
		</td>
	</tr>
	<tr>
		<td valign="top" class="picture">
			<?php echo $report_abuse_body;?><br />
		</td>
	</tr>
</table>
